@@ -19,7 +19,7 @@ module Copilot.Arduino.Library.Serial.Device (
 import Copilot.Arduino hiding (show)
 import Copilot.Arduino.Internals
 import Control.Monad.Writer
-import Copilot.Language.Stream (Arg)
+import Copilot.Language.Spec (Arg)
 import Data.List
 import Data.Maybe
 import Data.Proxy
